@@ -6,7 +6,7 @@ use base qw(Exporter);
 
 our @EXPORT = qw|ListWindows AdjustWindow|;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 sub ListWindows($)
 {
@@ -66,54 +66,55 @@ Win32::WindowGeometry - Simple module to search for open windows by title and mo
 
 =head1 SYNOPSIS
 
-	use Win32::WindowGeometry;
+    use Win32::WindowGeometry;
      
     my @all_windows = ListWindows('');
     foreach(@all_windows)
-	{
+    {
         if($_ =~ m/firefox/i)
         {
-			AdjustWindow($_, 0, 0, 1024, 768);
+            AdjustWindow($_, 0, 0, 1024, 768);
         }
     }
-	
-	my @specific_windows = ListWindows('chrome');
-	foreach(@specific_windows)
-	{
-		AdjustWindow($_, 50, 0, 800, 600);
-	}
-     
-	my $super_specific_window = ListWindows('zoom - meeting');
-	if(length($super_specific_window))
-	{
-		AdjustWindow($super_specific_window, 0, 0, 1920, 1080);
-	}
+
+    my @specific_windows = ListWindows('chrome');
+    foreach(@specific_windows)
+    {
+        AdjustWindow($_, 50, 0, 800, 600);
+    }
+
+    my $super_specific_window = ListWindows('zoom - meeting');
+    if(length($super_specific_window))
+    {
+        AdjustWindow($super_specific_window, 0, 0, 1920, 1080);
+    }
 
 =head1 DESCRIPTION
 
 Simple module to search for open windows by title and move/resize them.
+
 Pollutes the namespace with two functions: ListWindows & AdjustWindow.
 
 =head1 METHODS
 
 =head2 ListWindows
 
-ListWindows('search_string'); # case insensitive
-
-Returns a list of open windows whose titles match (or partially match)
-the provided argument.
-
 ListWindows('');
 
 Returns a list of all open windows.
 
+ListWindows('search_string'); # case insensitive
+
+Returns a list of open windows whose titles match (or partially match)
+the provided 'search_string' argument.
+
 =head2 AdjustWindow
 
 AdjustWindow('full_window_title_string', int_X_Position, int_Y_Position, int_X_Dimension, int_Y_Dimension);
 
 Sets a window (provided by the full name of the window's title) to an x,y position with an x,y dimension.
 
-=head1 NOTES
+=head1 Notes
 
 I just whipped this up out of necessity when I had a project where I
 needed to automate arranging/resizing some windows. I tried using an
@@ -124,20 +125,26 @@ There is plenty of information around the web on how to 'FindWindow',
 'GetWindow', etc. But not so much about moving/resizing windows. It
 seemed like a good idea to put this out for the community.
 
-Fair warning - this has not been rigorously tested, and there's not
-a great deal of error checking or data validation going on under the
-hood. You may want to add some of your own checks/validations for
-safety/functionality.
+=head1 Warning
+
+This has not been rigorously tested, and there's not a great deal of
+error checking or data validation going on under the hood. You may
+want to add some of your own checks/validations for safety/functionality.
 
 =head1 Version History
 
 1.01 - Initial Release
 
-=head1 AUTHOR, COPYRIGHT, and LICENSE
+1.02 - Fixed this POD document
 
-Copyright(C) 2020, phatWares, USA. All rights reserved.
+=head1 Author
+
+Brandon Bourret
+
+=head1 License
 
 Permission is granted to use this software under the same terms as Perl itself.
+
 Refer to the L<Perl Artistic|perlartistic> license for details.
 
 =cut
\ No newline at end of file
